LoadingFlipping class

Creates a loading animation that flips horizontally 3 times

Inheritance

Constructors

LoadingFlipping.circle({Key? key, AnimationController? controller, Color borderColor = Colors.blueGrey, Color backgroundColor = Colors.transparent, double size = 50.0, double? borderSize, IndexedWidgetBuilder? itemBuilder, Duration duration = const Duration(milliseconds: 1500)})
Creates the LoadingFlipping animation with a circle shape
const
LoadingFlipping.square({Key? key, AnimationController? controller, Color borderColor = Colors.blueGrey, Color backgroundColor = Colors.transparent, double size = 50.0, double? borderSize, IndexedWidgetBuilder? itemBuilder, Duration duration = const Duration(milliseconds: 1500)})
Creates the LoadingFlipping animation with a square shape
const

Properties

backgroundColor → Color
The color of the shape itself.
final
borderColor → Color
The color of the border of the shape.
final
borderSize → double?
Size of the border of the shape.
final
color → Color?
The progress indicator's color.
finalinherited
controller → AnimationController?
Sets an AnimationController is case you need to do something specific with it like play/pause animation.
final
duration → Duration
Total duration for one cycle of animation.
final
hashCode → int
The hash code for this object.
no setterinherited
itemBuilder → IndexedWidgetBuilder?
Sets an IndexedWidgetBuilder function to return your own customized widget.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel → String?
The SemanticsProperties.label for this progress indicator.
finalinherited
semanticsValue → String?
The SemanticsProperties.value for this progress indicator.
finalinherited
size → double
Size of the whole square containing the animation.
final
value → double?
If non-null, the value of this progress indicator.
finalinherited
valueColor → Animation<Color?>?
The progress indicator's color as an animated value.
finalinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _LoadingFlippingState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited